Macro unsafe_unpinned
macro_rules! unsafe_unpinned {
($f:tt: $t:ty) => { ... };
}
An unpinned projection of a struct field.
Safety
This macro is unsafe because it creates a method that returns a normal non-pin reference to the struct field. It is up to the programmer to ensure that the contained value can be considered not pinned in the current context.
Example
use unsafe_unpinned;
use Pin;
;
Note: borrowing the field multiple times requires using .as_mut() to
avoid consuming the Pin.